package com.hssx.cloudmodel.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.hssx.cloudmodel.entity.Company;
import com.hssx.cloudmodel.entity.Role;
import com.hssx.cloudmodel.service.CompanyService;
import com.hssx.cloudmodel.util.HttpRespMsg;
import com.hssx.cloudmodel.util.PageUtil;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


/**
 * @author 吴涛涛
 * @since 2019-07-26
 */
@Controller
@RequestMapping("/company")
@Slf4j
public class CompanyController {

    @Autowired
    private CompanyService companyService;

    /**
     * 添加/修改公司
     *
     * @param company 参数：companyName 公司名 companyAddress 公司地址
     * @param flag    0-添加，1-修改
     * @return
     */
    @ApiOperation("添加/修改公司")
    @RequestMapping("/add")
    @ResponseBody
    public HttpRespMsg addAndUpdateRole(Company company, HttpServletRequest request, Integer flag,
                                        HttpServletResponse response) {
        HttpRespMsg msg = new HttpRespMsg();
        msg = companyService.addAndUpdateRole(company, flag);
        return msg;
    }

    /**
     * 删除公司
     *
     * @param company 参数 id 公司id
     * @return
     */
    @ApiOperation("删除公司")
    @RequestMapping("/delete")
    @ResponseBody
    public HttpRespMsg delete(Company company, HttpServletRequest request,
                              HttpServletResponse response) {
        HttpRespMsg msg = new HttpRespMsg();
        msg.data = companyService.removeById(company.getId());
        return msg;
    }

    /**
     * 公司列表
     * 参数：pageNum 当前页码，pageSize 每页条数 keyName 关键字查询
     * @return
     */
    @ApiOperation("公司列表")
    @RequestMapping("/list")
    @ResponseBody
    public HttpRespMsg deleteRole(@RequestParam(required = false)String keyName, HttpServletRequest request,
                                  HttpServletResponse response, PageUtil page) {
        HttpRespMsg msg = new HttpRespMsg();
        msg = companyService.pageList(page,keyName);
        return msg;
    }

}

