package com.hssx.cloudmodel.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.hssx.cloudmodel.entity.Role;
import com.hssx.cloudmodel.entity.User;
import com.hssx.cloudmodel.mapper.RoleMapper;
import com.hssx.cloudmodel.mapper.UserMapper;
import com.hssx.cloudmodel.service.RoleService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hssx.cloudmodel.util.HttpRespMsg;
import com.hssx.cloudmodel.util.PageUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author 吴涛涛
 * @since 2019-07-26
 */
@Service
public class RoleServiceImpl extends ServiceImpl<RoleMapper, Role> implements RoleService {
    @Autowired
    RoleMapper roleMapper;
    @Autowired
    UserMapper userMapper;

    @Override
    public HttpRespMsg addAndUpdateRole(Role role, Integer flag) {
        HttpRespMsg msg = new HttpRespMsg();
        if (flag == 0) {
            //添加角色
            QueryWrapper<Role> qw = new QueryWrapper<>();
            qw.eq("role_name", role.getRoleName());
            int count = roleMapper.selectCount(qw);
            if (count > 0) {
                msg.setError("角色已存在，请勿重复添加");
            } else {
                roleMapper.insert(role);
            }
        } else if (flag == 1) {
            //更新角色信息
            roleMapper.updateById(role);
        }
        return msg;

    }

    @Override
    public HttpRespMsg pageList(PageUtil page, String keyName) {
        HttpRespMsg msg = new HttpRespMsg();
        QueryWrapper<Role> qw = new QueryWrapper<>();
        Integer start = (page.getPageNum() - 1) * page.getPageSize();
        if (keyName != null && !"".equals(keyName)) {
            qw.like("role_name", keyName);
        }
        Integer count = roleMapper.selectCount(qw);
        page.setTotal(count);
        page.setPages(page.getTotal());
        List<Role> list = roleMapper.getListByKeyName(keyName, start, page.getPageSize());
        page.setList(list);
        msg.data = page;
        return msg;
    }

    @Override
    public List<Role> getIdAndNamelist() {
        return roleMapper.selectIdAndNamelist();
    }

    @Override
    public HttpRespMsg deleteById(Integer id) {
        HttpRespMsg msg = new HttpRespMsg();
        Integer count = userMapper.selectCount(new QueryWrapper<User>().eq("role_type", id));
        if (count > 0) {
            msg.setError("该角色已被应用到用户中，暂不提供删除操作");
        } else {
            roleMapper.deleteById(id);
        }
        return msg;
    }
}
